@@ -14,6 +14,7 @@ from typing import (
 )
 
 import pystac
+from pystac.layout import APILayoutStrategy, HrefLayoutStrategy
 
 from pystac_client._utils import Modifiable, call_modifier
 from pystac_client.conformance import ConformanceClasses
@@ -32,6 +33,7 @@ if TYPE_CHECKING:
 class CollectionClient(pystac.Collection, QueryablesMixin):
     modifier: Callable[[Modifiable], None]
     _stac_io: StacApiIO
+    _fallback_strategy: HrefLayoutStrategy = APILayoutStrategy()
 
     def __init__(
         self,
@@ -47,11 +49,12 @@ class CollectionClient(pystac.Collection, QueryablesMixin):
         keywords: Optional[List[str]] = None,
         providers: Optional[List[pystac.Provider]] = None,
         summaries: Optional[pystac.Summaries] = None,
+        assets: Optional[Dict[str, pystac.Asset]] = None,
+        strategy: Optional[HrefLayoutStrategy] = None,
         *,
         modifier: Optional[Callable[[Modifiable], None]] = None,
         **kwargs: Dict[str, Any],
     ):
-        # TODO(pystac==1.6.0): Add `assets` as a regular keyword
         super().__init__(
             id,
             description,
@@ -65,6 +68,8 @@ class CollectionClient(pystac.Collection, QueryablesMixin):
             keywords,
             providers,
             summaries,
+            assets,
+            strategy,
             **kwargs,
         )
         # error: Cannot assign to a method  [assignment]
