@@ -42,8 +42,7 @@ DATETIME_REGEX = re.compile(
 
 class GeoInterface(Protocol):
     @property
-    def __geo_interface__(self) -> Dict[str, Any]:
-        ...
+    def __geo_interface__(self) -> Dict[str, Any]: ...
 
 
 DatetimeOrTimestamp = Optional[Union[datetime_, str]]
@@ -180,11 +179,10 @@ class ItemSearch:
         bbox: A list, tuple, or iterator representing a bounding box of 2D
             or 3D coordinates. Results will be filtered
             to only those intersecting the bounding box.
-        intersects: A string or dictionary representing a GeoJSON geometry, or
-            an object that implements a
-            ``__geo_interface__`` property, as supported by several libraries
-            including Shapely, ArcPy, PySAL, and
-            geojson. Results filtered to only those intersecting the geometry.
+        intersects: A string or dictionary representing a GeoJSON geometry or feature,
+            or an object that implements a ``__geo_interface__`` property, as supported
+            by several libraries including Shapely, ArcPy, PySAL, and geojson. Results
+            filtered to only those intersecting the geometry.
         datetime: Either a single datetime or datetime range used to filter results.
             You may express a single datetime using a :class:`datetime.datetime`
             instance, a `RFC 3339-compliant <https://tools.ietf.org/html/rfc3339>`__
@@ -439,7 +437,8 @@ class ItemSearch:
 
     @staticmethod
     def _to_utc_isoformat(dt: datetime_) -> str:
-        dt = dt.astimezone(timezone.utc)
+        if dt.tzinfo is not None:
+            dt = dt.astimezone(timezone.utc)
         dt = dt.replace(tzinfo=None)
         return f'{dt.isoformat("T")}Z'
 
@@ -633,12 +632,12 @@ class ItemSearch:
                 includes.append(field[1:])
             else:
                 includes.append(field)
-        return {"includes": includes, "excludes": excludes}
+        return {"include": includes, "exclude": excludes}
 
     @staticmethod
     def _fields_dict_to_str(fields: Fields) -> str:
-        includes = [f"+{x}" for x in fields.get("includes", [])]
-        excludes = [f"-{x}" for x in fields.get("excludes", [])]
+        includes = [f"+{x}" for x in fields.get("include", [])]
+        excludes = [f"-{x}" for x in fields.get("exclude", [])]
         return ",".join(chain(includes, excludes))
 
     @staticmethod
@@ -646,7 +645,10 @@ class ItemSearch:
         if value is None:
             return None
         if isinstance(value, dict):
-            return deepcopy(value)
+            if value.get("type") == "Feature":
+                return deepcopy(value.get("geometry"))
+            else:
+                return deepcopy(value)
         if isinstance(value, str):
             return dict(json.loads(value))
         if hasattr(value, "__geo_interface__"):
